==> manage-service-api-0.0.1-20211118.071144-37-sources.jar: cn/com/duiba/cloud/manage/service/api/remoteservice/staff/RemoteStaffService.java <==
package cn.com.duiba.cloud.manage.service.api.remoteservice.staff;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.cloud.manage.service.api.model.dto.staff.StaffDTO;
import cn.com.duiba.cloud.manage.service.api.model.param.RemoteIdParam;
import cn.com.duiba.cloud.manage.service.api.model.param.staff.RemoteChangeStaffIdentityParam;
import cn.com.duiba.cloud.manage.service.api.model.param.staff.RemoteGetStaffByDeptIdRequest;
import cn.com.duiba.cloud.manage.service.api.model.param.staff.RemoteGetStaffRequest;
import cn.com.duiba.cloud.manage.service.api.model.param.staff.RemoteUpdateStaffDeptParam;
import cn.com.duiba.wolf.entity.PageResponse;

/**
 * 角色员工远程服务
 * @author jiangyesheng
 * @version 1.0
 * @date 2021/11/8
 */
@AdvancedFeignClient
public interface RemoteStaffService {

    /**
     * 删除员工
     * @param staffId
     * @return
     * @throws BizException
     */
    Long delStaff(RemoteIdParam staffId) throws BizException;

    /**
     * 变更部门 同时变成普通员工
     *
     * @param param
     * @return
     * @throws BizException
     */
    Boolean updateStaffDept(RemoteUpdateStaffDeptParam param);

    /**
     * 变更部门下员工身份
     *
     * @param param
     * @return
     * @throws BizException
     */
    Boolean changeStaffIdentity(RemoteChangeStaffIdentityParam param) throws BizException;

    /**
     * 获取指定部门下的员工数据 分页
     *
     * @param param
     * @return
     * @throws BizException
     */
    PageResponse<StaffDTO> getStaffByDeptId(RemoteGetStaffByDeptIdRequest param);

    /**
     * 获取员工详情
     *
     * @param staffId 员工id
     * @return
     * @throws BizException
     */
    StaffDTO getStaff(RemoteGetStaffRequest staffId) throws BizException;

}

==> manage-service-api-0.0.1-20211122.092959-62-sources.jar: cn/com/duiba/cloud/manage/service/api/remoteservice/staff/RemoteStaffService.java <==
package cn.com.duiba.cloud.manage.service.api.remoteservice.staff;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.cloud.manage.service.api.model.dto.staff.StaffDTO;
import cn.com.duiba.cloud.manage.service.api.model.param.RemoteIdParam;
import cn.com.duiba.cloud.manage.service.api.model.param.staff.RemoteChangeStaffIdentityParam;
import cn.com.duiba.cloud.manage.service.api.model.param.staff.RemoteGetStaffByDeptIdRequest;
import cn.com.duiba.cloud.manage.service.api.model.param.staff.RemoteGetStaffRequest;
import cn.com.duiba.cloud.manage.service.api.model.param.staff.RemoteSaveStaffRequest;
import cn.com.duiba.cloud.manage.service.api.model.param.staff.RemoteUpdateStaffDeptParam;
import cn.com.duiba.wolf.entity.JsonResult;
import cn.com.duiba.wolf.entity.PageResponse;
import org.springframework.web.bind.annotation.RequestBody;

/**
 * 角色员工远程服务
 * @author jiangyesheng
 * @version 1.0
 * @date 2021/11/8
 */
@AdvancedFeignClient
public interface RemoteStaffService {

    /**
     * 删除员工
     * @param staffId
     * @return
     * @throws BizException
     */
    Long delStaff(RemoteIdParam staffId) throws BizException;

    /**
     * 变更部门 同时变成普通员工
     *
     * @param param
     * @return
     * @throws BizException
     */
    Boolean updateStaffDept(RemoteUpdateStaffDeptParam param);

    /**
     * 变更部门下员工身份
     *
     * @param param
     * @return
     * @throws BizException
     */
    Boolean changeStaffIdentity(RemoteChangeStaffIdentityParam param) throws BizException;

    /**
     * 获取指定部门下的员工数据 分页
     *
     * @param param
     * @return
     * @throws BizException
     */
    PageResponse<StaffDTO> getStaffByDeptId(RemoteGetStaffByDeptIdRequest param);

    /**
     * 获取员工详情
     *
     * @param staffId 员工id
     * @return
     * @throws BizException
     */
    StaffDTO getStaff(RemoteGetStaffRequest staffId) throws BizException;

    Long updateStaff( RemoteSaveStaffRequest param) throws BizException;

}
